@@ -17,7 +17,7 @@ __all__ = (
     "OutputTest",
     "CompareTest",
     "CompareBytesOutputTest",
-    "ExecutableMixin",
+    "ExecutableOutputMixin",
     "ExecutableCodeMixin",
     "ExecutableInputFileMixin",
     "ExecutableOutputFileMixin",
@@ -185,7 +185,7 @@ def test_runtime_succeeded(runtime: Runtime) -> CorrectnessResult:
     if runtime.timed_out:
         error = Error(
             description="timed out",
-            suggestion=f"expected maximum elapsed time of {runtime.timeout} seconds")
+            suggestion=f"exceeded maximum elapsed time of {runtime.timeout} seconds")
         raise CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
     if runtime.code != 0:
         error = Error(
@@ -194,7 +194,7 @@ def test_runtime_succeeded(runtime: Runtime) -> CorrectnessResult:
         return CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
 
 
-class ExecutableMixin(OutputTest, Configurable):
+class ExecutableOutputMixin(Configurable):
     """Meant for reading and comparing stdout."""
 
     executable_name: str
@@ -221,7 +221,7 @@ class ExecutableMixin(OutputTest, Configurable):
         self.timeout = timeout
         self.cwd = cwd
 
-    def execute(self) -> Runtime:
+    def execute(self: Union["ExecutableOutputMixin", OutputTest]) -> Runtime:
         """Check that it ran correctly, then run the test."""
 
         executable = self.resources[self.executable_name]
@@ -241,7 +241,7 @@ class ExecutableMixin(OutputTest, Configurable):
         return runtime.stdout
 
 
-class ExecutableCodeMixin(ExecutableMixin):
+class ExecutableCodeMixin(ExecutableOutputMixin):
     """Output is exit code instead of stdout."""
 
     def get_output(self) -> Any:
@@ -319,7 +319,7 @@ class CompareExitCodeOutputTest(OutputTest, Configurable):
             return CorrectnessResult(
                 passing=False,
                 error=Error(
-                    description=f"received incorrect exit code f{code}",
+                    description=f"received incorrect exit code {code}",
                     suggestion=f"expected {expected_codes}"))
 
         self.test = test
